/***************************************************************************
 *   Copyright (C) 2007-2012 by Tobias Schwarz   *
 *   mail@tobias-schwarz.net   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#ifndef CONFIGDLG_H
#define CONFIGDLG_H

#include "settings.h"
#include "kemboss.h"
#include "ui_configDlg.h"

class configDlg : public QDialog, private Ui::ConfigDialog
{
    Q_OBJECT

public:
    configDlg(kemboss *parent = 0, kembossSettings *fksettings = 0);

private slots:
    void accept();
    void helpRequested();
    void fontChanged() { fontHasChanged = true; };
    void embassyChanged() { embassyHasChanged = true; };
    void on_StyleComboBox_activated(const QString &text);
    void on_KembossDataPushButton_clicked() { setExistingDir(tr("Select kemboss data directory"), KembossDataLineEdit); }
    void on_KembossDefaultSettingsPushButton_clicked() { setExistingDir(tr("Select kemboss default settings directory"), KembossDefaultSettingsLineEdit); }
    void on_EmbossBinPushButton_clicked() { setExistingDir(tr("Select EMBOSS binaries directory"), EmbossBinLineEdit); }
    void on_EmbossHelpPushButton_clicked() { setExistingDir(tr("Select EMBOSS helpfiles directory"), EmbossHelpLineEdit); }
    void on_EmbossDataPushButton_clicked() { setExistingDir(tr("Select EMBOSS data directory"), EmbossDataLineEdit); }
    void on_BasicAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->basic_aa.foreground().color(), this); ksettings->basic_aa.setForeground(color); BasicAAPushButton->setPalette(QPalette(color)); }
    void on_CysteinPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->cystein.foreground().color(), this); ksettings->cystein.setForeground(color); CysteinPushButton->setPalette(QPalette(color)); }
    void on_ApolarAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->apolar_aa.foreground().color(), this); ksettings->apolar_aa.setForeground(color); ApolarAAPushButton->setPalette(QPalette(color)); }
    void on_PolarAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->polar_aa.foreground().color(), this); ksettings->polar_aa.setForeground(color); PolarAAPushButton->setPalette(QPalette(color)); }
    void on_AcidicAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->acidic_aa.foreground().color(), this); ksettings->acidic_aa.setForeground(color); AcidicAAPushButton->setPalette(QPalette(color)); }
    void on_DibasicAAPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->dibasic_aa.foreground().color(), this); ksettings->dibasic_aa.setForeground(color); DibasicAAPushButton->setPalette(QPalette(color)); }
    void on_ANucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->a_nuc.foreground().color(), this); ksettings->a_nuc.setForeground(color); ANucPushButton->setPalette(QPalette(color)); }
    void on_TNucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->t_nuc.foreground().color(), this); ksettings->t_nuc.setForeground(color); TNucPushButton->setPalette(QPalette(color)); }
    void on_GNucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->g_nuc.foreground().color(), this); ksettings->g_nuc.setForeground(color); GNucPushButton->setPalette(QPalette(color)); }
    void on_CNucPushButton_clicked() { QColor color=QColorDialog::getColor(ksettings->c_nuc.foreground().color(), this); ksettings->c_nuc.setForeground(color); CNucPushButton->setPalette(QPalette(color)); }
    void on_OnlineDocCheckBox_stateChanged(int state);

private:
    void readSettings();
    void writeSettings();
    void setExistingDir(const QString &dlgMsg, QLineEdit *lineEdit);
    void setOpenFile(const QString &dlgMsg, QLineEdit *lineEdit);
    void setSaveFile(const QString &dlgMsg, QLineEdit *lineEdit);
    bool fontHasChanged;
    bool embassyHasChanged;
    kemboss *mainKembossWindow;
    kembossSettings *ksettings;
};

#endif
