/***************************************************************************
 *   Copyright (C) 2007-2012 by Tobias Schwarz                             *
 *   mail@tobias-schwarz.net                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#ifndef RUNEMBOSSAPP_H
#define RUNEMBOSSAPP_H

#ifdef KEMBOSS_CLIENT
   #include <QtNetwork>
   #include <QTcpSocket>
#endif
#include "programProgress.h"
#include "settings.h"

class krunEmbossApp : public QObject
{
   Q_OBJECT

public:
    krunEmbossApp(QWidget *parent = 0, kembossSettings *fksettings = 0);
    virtual ~krunEmbossApp() {}
    virtual void setEmbossApp(const QString &appName) { if (!appName.isEmpty()) cembossApp = appName; }
    QString embossApp() { return cembossApp; }
    QStringList programConfiguration;
    bool runApp();
    bool localEmbossInstallation;

private slots:
    void updateProgramProgressForm();
    void processFinished(int exitCode);
    void killProcess();

#ifdef KEMBOSS_CLIENT
    void runEmbossAppOnServer();
    void readEmbossOutput();
    void displayError(QAbstractSocket::SocketError socketError);
    void sessionOpened();
#endif

private:
    bool checkEmbossApp();
    void runEmbossAppLocal();
    QWidget *parentWindow;
    kembossSettings *ksettings;
    QProcess programProcess;
    programProgressForm *programProgress;
    QTime runTime;
    QString cembossApp;

#ifdef KEMBOSS_CLIENT
    bool startKembossClient();
    void closeKembossClient();
    QTcpSocket *tcpSocket;
    QString currentFortune;
    quint16 blockSize;
    QNetworkSession *networkSession;
    QString Username;
    QString Pass;
    QString Hostname;
    int Port;
#endif

protected:
    virtual void beforeRunningProgram();
    virtual void afterRunningProgram();

};

#endif // RUNEMBOSSAPP_H
