/***************************************************************************
 *   Copyright (C) 2007-2010 by Tobias Schwarz                             *
 *   mail@tobias-schwarz.net                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 *                                                                         *
 *   In addition, as a special exception, the copyright holders give       *
 *   permission to link the code of this program with any edition of       *
 *   the Qt library by Trolltech AS, Norway (or with modified versions     *
 *   of Qt that use the same license as Qt), and distribute linked         *
 *   combinations including the two.  You must obey the GNU General        *
 *   Public License in all respects for all of the code used other than    *
 *   Qt.  If you modify this file, you may extend this exception to        *
 *   your version of the file, but you are not obligated to do so.  If     *
 *   you do not wish to do so, delete this exception statement from        *
 *   your version.                                                         *
 ***************************************************************************/

#include "settings.h"
#include <QtGui>

kembossSettings::kembossSettings()
{
   readSettings();
}

void kembossSettings::readSettings()
{
   // Load settings from configuration file / registry
   QSettings settings(QSettings::UserScope, "kemboss.org", "Configuration");

   ckembossData = settings.value("kemboss_data").toString();
   ckembossDefaultSettings = settings.value("kemboss_default_settings").toString();
   cembossBin = settings.value("emboss_bin").toString();
   cembossHelp = settings.value("emboss_help").toString();
   cuseOnlineDoc = settings.value("use_online_doc", false).toBool();
   cembossData = settings.value("emboss_data").toString();
   ccurrentDir = settings.value("current_dir", QDir::homePath()).toString();
   copenLastSettings = settings.value("open_last_settings", false).toBool();
   cautoCloseProgressWindow = settings.value("auto_close_progress_window", false).toBool();
   cautoShowOutputTab = settings.value("auto_show_output_tab", true).toBool();
   cautoDeleteExistingOutputFile = settings.value("auto_delete_existing_output_file", true).toBool();
   cmaxExeTime = settings.value("max_execution_time", 30000).toInt();
   settextEditFont(settings.value("text_edit_font_family", "courier").toString(),settings.value("text_edit_font_size", 10).toInt());
   setwrapLines(settings.value("text_edit_wrap_lines", false).toBool());
   cystein.setForeground(settings.value("cystein_color",Qt::darkGreen).value<QColor>());
   apolar_aa.setForeground(settings.value("apolar_aa_color",Qt::darkYellow).value<QColor>());
   polar_aa.setForeground(settings.value("polar_aa_color",Qt::darkGreen).value<QColor>());
   acidic_aa.setForeground(settings.value("acidic_aa_color",Qt::red).value<QColor>());
   basic_aa.setForeground(settings.value("basic_aa_color",Qt::blue).value<QColor>());
   dibasic_aa.setForeground(settings.value("dibasic_aa_color",Qt::blue).value<QColor>());
   a_nuc.setForeground(settings.value("a_nuc_color",Qt::green).value<QColor>());
   t_nuc.setForeground(settings.value("t_nuc_color",Qt::red).value<QColor>());
   g_nuc.setForeground(settings.value("g_nuc_color",Qt::black).value<QColor>());
   c_nuc.setForeground(settings.value("c_nuc_color",Qt::blue).value<QColor>());
   seq_name.setForeground(Qt::black);
   seq_name.setFontWeight(QFont::Bold);
   comment.setForeground(Qt::gray);
   comment.setFontItalic(true);
   cystein.setFontWeight(QFont::Bold);
}

void kembossSettings::writeSettings() const
{
   QSettings settings(QSettings::UserScope, "kemboss.org", "Configuration");

   settings.setValue("kemboss_data", ckembossData);
   settings.setValue("kemboss_default_settings", ckembossDefaultSettings);
   settings.setValue("emboss_bin", cembossBin);
   settings.setValue("emboss_help", cembossHelp);
   settings.setValue("use_online_doc", cuseOnlineDoc);
   settings.setValue("emboss_data", cembossData);
   settings.setValue("current_dir", ccurrentDir);
   settings.setValue("open_last_settings", copenLastSettings);
   settings.setValue("auto_close_progress_window", cautoCloseProgressWindow);
   settings.setValue("auto_show_output_tab", cautoShowOutputTab);
   settings.setValue("auto_delete_existing_output_file", cautoDeleteExistingOutputFile);
   settings.setValue("max_execution_time", cmaxExeTime);
   settings.setValue("text_edit_font_family", textEditFont().family());
   settings.setValue("text_edit_font_size", textEditFont().pointSize());
   settings.setValue("text_edit_wrap_lines", wrapLines());
   settings.setValue("cystein_color",cystein.foreground().color());
   settings.setValue("apolar_aa_color",apolar_aa.foreground().color());
   settings.setValue("polar_aa_color",polar_aa.foreground().color());
   settings.setValue("acidic_aa_color",acidic_aa.foreground().color());
   settings.setValue("basic_aa_color",basic_aa.foreground().color());
   settings.setValue("dibasic_aa_color",dibasic_aa.foreground().color());
   settings.setValue("a_nuc_color",a_nuc.foreground().color());
   settings.setValue("t_nuc_color",t_nuc.foreground().color());
   settings.setValue("g_nuc_color",g_nuc.foreground().color());
   settings.setValue("c_nuc_color",c_nuc.foreground().color());
}

bool kembossSettings::checkSettings()
{
   // Check if all directories exist. If not check the usual suspects.
   bool allDirsExist = true;
   if (ckembossData.isEmpty() || !QDir(ckembossData).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/kemboss/data").exists()) setkembossData("/usr/share/kemboss/data/");
      else if (QDir("/usr/local/share/kemboss/data").exists()) setkembossData("/usr/local/share/kemboss/data/");
      else if (QDir("/sw/share/kemboss/data").exists()) setkembossData("/sw/share/kemboss/data/");
      else if (QDir("/Applications/kemboss.app/Contents/Resources/data").exists()) setkembossData("/Applications/kemboss.app/Contents/Resources/data/");
      else
      #endif
      #ifdef Q_WS_WIN
      if (QDir(QCoreApplication::applicationDirPath()+"\\data").exists()) setkembossData(QCoreApplication::applicationDirPath()+"\\data\\");
      else
      #endif
      allDirsExist = false;
   }
   if (ckembossDefaultSettings.isEmpty() || !QDir(ckembossDefaultSettings).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/kemboss/default_settings").exists()) setkembossDefaultSettings("/usr/share/kemboss/default_settings/");
      else if (QDir("/usr/local/share/kemboss/default_settings").exists()) setkembossDefaultSettings("/usr/local/share/kemboss/default_settings/");
      else if (QDir("/etc/kemboss/default_settings").exists()) setkembossDefaultSettings("/etc/kemboss/default_settings/");
      else if (QDir("/sw/etc/kemboss/default_settings").exists()) setkembossDefaultSettings("/sw/etc/kemboss/default_settings/");
      else if (QDir("/Applications/kemboss.app/Contents/Resources/default_settings").exists()) setkembossDefaultSettings("/Applications/kemboss.app/Contents/Resources/default_settings/");
      else
      #endif
      #ifdef Q_WS_WIN
      if (QDir(QCoreApplication::applicationDirPath()+"\\default_settings").exists()) setkembossDefaultSettings(QCoreApplication::applicationDirPath()+"\\default_settings\\");
      else
      #endif
      allDirsExist = false;
   }
   if (cembossBin.isEmpty() || !QDir(cembossBin).exists()) {
      #ifdef Q_WS_X11
      if (QFile::exists("/usr/bin/embossversion")) setembossBin("/usr/bin/");
      else if (QFile::exists("/usr/local/bin/embossversion")) setembossBin("/usr/local/bin/");
      else if (QFile::exists("/sw/bin/embossversion")) setembossBin("/sw/bin/");
      else
      #endif
      #ifdef Q_WS_WIN
      QStringList environment = QProcess::systemEnvironment();
      QString path = environment.at(environment.indexOf(QRegExp("^EMBOSS_ROOT=(.*)", Qt::CaseInsensitive)));
      if (QDir(path.mid(12)).exists()) setembossBin(path.mid(12));
      else
      #endif
      allDirsExist = false;
   }
   if (cembossHelp.isEmpty() || !QDir(cembossHelp).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/EMBOSS/doc/html/emboss/apps").exists()) setembossHelp("/usr/share/EMBOSS/doc/html/emboss/apps/");
      else if (QDir("/usr/share/EMBOSS/doc/programs/html").exists()) setembossHelp("/usr/share/EMBOSS/doc/programs/html/");
      else if (QDir("/usr/local/share/EMBOSS/doc/html/emboss/apps").exists()) setembossHelp("/usr/local/share/EMBOSS/doc/html/emboss/apps/");
      else if (QDir("/usr/local/share/EMBOSS/doc/programs/html").exists()) setembossHelp("/usr/local/share/EMBOSS/doc/programs/html/");
      else if (QDir("/usr/local/share/doc/packages/EMBOSS/html/emboss/apps").exists()) setembossHelp("/usr/local/share/doc/packages/EMBOSS/html/emboss/apps/");
      else if (QDir("/usr/local/share/doc/packages/EMBOSS/programs/html").exists()) setembossHelp("/usr/local/share/doc/packages/EMBOSS/programs/html/");
      else if (QDir("/sw/share/EMBOSS/doc/programs/html").exists()) setembossHelp("/sw/share/EMBOSS/doc/programs/html/");
      else
      #endif
      #ifdef Q_WS_WIN
      if (QDir(embossBin()+"doc\\programs\\html").exists()) setembossHelp(embossBin()+"doc\\programs\\html\\");
      else
      #endif
      allDirsExist = false;
   }
   if (cembossData.isEmpty() || !QDir(cembossData).exists()) {
      #ifdef Q_WS_X11
      if (QDir("/usr/share/EMBOSS/data").exists()) setembossData("/usr/share/EMBOSS/data/");
      else if (QDir("/usr/local/share/EMBOSS/data").exists()) setembossData("/usr/local/share/EMBOSS/data/");
      else if (QDir("/sw/share/EMBOSS/data").exists()) setembossData("/sw/share/EMBOSS/data/");
      else
      #endif
      #ifdef Q_WS_WIN
      QStringList environment = QProcess::systemEnvironment();
      QString path = environment.at(environment.indexOf(QRegExp("^EMBOSS_DATA=(.*)", Qt::CaseInsensitive)));
      if (QDir(path.mid(12)).exists()) setembossData(path.mid(12));
      else if (QDir(embossBin()+"data").exists()) setembossData(embossBin()+"data\\");
      else
      #endif
      allDirsExist = false;
   }
   return allDirsExist;
}
